function handles = f_HXplot(handles,varargin)

if nargin>1
    teta=varargin{1};
    pvap=varargin{2};
end


xmin=-20;
xmax=30;
%saturation vapour pressure at Tmax
if xmax<=0
    psat=610.5*exp(21.875*(xmax)/(265.5+xmax));%[Pa]
else
    psat=610.5*exp(17.269*(xmax)/(237.3+xmax));%[Pa]
end
Rd=461.5;%[J/kgK] specific gas constant of water
p_atm=101325;%[Pa]
cvmax=1000*psat/(Rd*(xmax+273.15));%[g/m^3]
x_max=1000*0.622*psat/(p_atm-psat);%[g/kg dry air]


Gas=1;%air
M_air=28.97;%[kg/kmol] - Molar mass of air
M_vap=18.01534;%[kg/kmol] - Molar mass of water
P=101325; %[Pa] - Atmospheric pressure
R=8314.41; %[J/kmol] - Universal Gas constant
g=9.81;%[m/s]
T=linspace(xmin,xmax,1000);%[K] - Absolute temperature

for i=1:length(T)
    [Cp(i),Rho(i),Lambda(i),Mu(i)] = f_gasprop(T(i),Gas);
    %Cp [J/kgK]
    %Rho [kg/m^3]
    %Lambda [W/mK]
    %Mu [kg/ms] - dynamic viscosity
    
    mode='Goff';
    switch mode
        case 'wufi'
            if T(i)<=0
                psat(i)=610.5*exp(21.875*(T(i))/(265.5+T(i)));
            else
                psat(i)=610.5*exp(17.269*(T(i))/(237.3+T(i)));
            end
        case 'Goff'
            %Goff & Gratch Equation (1946)
            Ts = 373.15;    % standard temperature at steam point on Kelvin scale (Goff, 1965)
            Ps = 101324.6;  % standard atmospheric pressure at steam point (Pascal)
            Ta=273.15+T(i);
            log10SVP = -7.90298*(Ts./Ta - 1) + 5.02808*log10(Ts./Ta) -1.3816e-7*(10.^(11.344*(1 - Ta./Ts)) - 1) + 8.1328e-3*(10.^(3.49149*(1 - Ts./Ta)) - 1) + log10(Ps);
            psat(i) = 10.^(log10SVP);
    end
    
    
end


ymin=0;
ymax=max(psat);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Plotting////////////////////////////////
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Psat
plot(T,psat,...
    'LineWidth',2,...
    'color','r',...
    'parent',handles.axes1);
hold(handles.axes1,'on');
tmp_x=xmin+(xmax-xmin)*0.95;
tmp_y=interp1(T,psat,tmp_x);
[x,j]=min(abs(T-tmp_x));%j - the index of the closest element in T to tmp_x
a=get(handles.axes1,'DataAspectRatio');%get the relative scaling of the axes
deltax=diff(T(j:j+1));
deltay=diff(psat(j:j+1));
rad=atan((deltay/a(2))/(deltax/a(1)));
deg=(rad/pi)*180;
text(tmp_x,tmp_y,...
    '100%',...
    'Color','r',...
    'HorizontalAlignment','center',...
    'BackgroundColor','w',...
    'Rotation',deg,...
    'parent',handles.axes1);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Pvap lines for fi:10-90%
for i=1:9
    plot(T,psat*0.1*i,...
        'color','b',...
        'parent',handles.axes1);
    tmp_y=interp1(T,psat*0.1*i,tmp_x);  
    deltax=diff(T(j:j+1));
    deltay=diff(psat(j:j+1)*0.1*i);
    rad=atan((deltay/a(2))/(deltax/a(1)));
    deg=(rad/pi)*180;
    text(tmp_x,tmp_y,...
        [num2str(i*10) '%'],...
        'Color','b',...
        'HorizontalAlignment','center',...
        'BackgroundColor','w',...
        'Rotation',deg,...
        'parent',handles.axes1);
end
%plot the red point
if handles.toplot.plotair==1
    teta=handles.toplot.teta;
    pvap=handles.toplot.pvap;
    h_1=plot([teta teta],[0 pvap],'--',...
        'LineWidth',2,...
        'color','k',...
        'parent',handles.axes1);
    h_2=plot([teta xmax],[pvap pvap],'--',...
        'LineWidth',2,...
        'color','b',...
        'parent',handles.axes1);
    h_3=plot([xmin teta],[pvap pvap],'--',...
        'LineWidth',2,...
        'color','r',...
        'parent',handles.axes1);
    h_4=plot(teta,pvap,'o',...
        'MarkerEdgeColor','r',...
        'MarkerFaceColor','r',...
        'parent',handles.axes1);   
end
%plot the blue point
if handles.toplot.plotsurf==1
    tetasurf=handles.toplot.tetasurf;
    pvap=handles.toplot.pvap;
    tetaext=handles.toplot.tetaext;
    if isnan(tetaext)==0
        plot([tetaext tetaext],[0 handles.toplot.psatext],'--',...
            'LineWidth',2,...
            'color','k',...
            'parent',handles.axes1);
    end
    if handles.toplot.psatsurf>=pvap
        plot([tetasurf tetasurf],[0 pvap],'--',...
            'LineWidth',2,...
            'color','k',...
            'parent',handles.axes1);
        h_5=plot(tetasurf,pvap,'o',...
            'MarkerEdgeColor','b',...
            'MarkerFaceColor','b',...
            'parent',handles.axes1);
    else
        plot([tetasurf tetasurf],[0 handles.toplot.psatsurf],'--',...
            'LineWidth',2,...
            'color','k',...
            'parent',handles.axes1);
        plot([tetasurf xmax],[handles.toplot.psatsurf handles.toplot.psatsurf],'--',...
            'LineWidth',2,...
            'color','b',...
            'parent',handles.axes1);
        plot([xmin tetasurf],[handles.toplot.psatsurf handles.toplot.psatsurf],'--',...
            'LineWidth',2,...
            'color','r',...
            'parent',handles.axes1);
        plot(tetasurf,pvap,'o',...
            'MarkerEdgeColor','b',...
            'parent',handles.axes1);
        h_5=plot(tetasurf,handles.toplot.psatsurf,'o',...
            'MarkerEdgeColor','b',...
            'MarkerFaceColor','b',...
            'parent',handles.axes1);
    end
end
ylabel(handles.axes1,'P_{vap} - Vapor pressure [Pa]');
set(handles.axes1,'YaxisLocation','right');
set(handles.axes1,'xlim',[-20 30]);
set(handles.axes1,'ylim',[0 max(psat)]);
%grid(handles.axes1,'on');
hold(handles.axes1,'off');
set(handles.axes1,'YColor','b',...
    'Xcolor','w');
set(handles.figure1,'units','centimeters');
set(handles.axes1,'units','centimeters');
set(handles.axes1,'box','off');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%plot specific enthalpy axes and lines
a=get(handles.axes2,'DataAspectRatio');%get the relative scaling of the axes
deg1=180*(atan(a(2)/a(1))/pi);
deg2=180*(atan(a(1)/a(2))/pi);
deg=(deg1+deg2)/2;
plot(T,T+5,...
    'color',[0.1 0.5 0],...
    'parent',handles.axes2);
hold(handles.axes2,'on');
text(10,17,...
    'Specific Enthalpy [kJ/kg dry air]',...
    'Color',[0.1 0.5 0],...
    'HorizontalAlignment','center',...
    'VerticalAlignment','baseline',...
    'Rotation',deg,...
    'parent',handles.axes2);
for h=0:10:90
    t0=h;
    t1=(h-12.5)/3.5;
    x1=t1+5;
    plot([t0,t1],[0,x1],...
        'Color',[0.1 0.5 0],...
        'parent',handles.axes2);
    text(t1-0.2,x1+0.2,...
        num2str(h),...
        'Color',[0.1 0.5 0],...
        'HorizontalAlignment','center',...
        'VerticalAlignment','baseline',...
        'Rotation',deg,...
        'parent',handles.axes2);
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%plot specific volume and wet bulb temperature lines
Rair=287;%[J/kgK] specific gas constant of air
for T1=[-20 -15 -10 -5 0 5 10 15 20 25 30];
    switch mode
        case 'wufi'
            if T1<=0
                psat=610.5*exp((21.875*T1)/(265.5+T1));
            else
                psat=610.5*exp((17.269*T1)/(237.3+T1));
            end
        case 'Goff'
            %Goff & Gratch Equation (1946)
            Ts = 373.15;    % standard temperature at steam point on Kelvin scale (Goff, 1965)
            Ps = 101324.6;  % standard atmospheric pressure at steam point (Pascal)
            Ta=273.15+T1;
            log10SVP = -7.90298*(Ts./Ta - 1) + 5.02808*log10(Ts./Ta) -1.3816e-7*(10.^(11.344*(1 - Ta./Ts)) - 1) + 8.1328e-3*(10.^(3.49149*(1 - Ts./Ta)) - 1) + log10(Ps);
            psat = 10.^(log10SVP);
    end
    vol=(Rair*(T1+273.15))/(p_atm-psat);%specific volume at saturation
    tv0=(p_atm*vol)/Rair-273.15;%air temperature at tero humidity
    x1=622*psat/(p_atm-psat);%saturation specific humidity
    plot([T1 tv0],[x1 0],...
        'color',[0.2 0.2 0.2],...
        'Parent',handles.axes2);
    if tv0<xmax & tv0>-10
        text(tv0,0.4,...
            sprintf('%1.4s',num2str(vol)),...
            'color',[0.2 0.2 0.2],...
            'HorizontalAlignment','Center',...
            'VerticalAlignment','baseline',...
            'parent',handles.axes2);
            %'BackgroundColor','w',...
    end
    h=T1+2.5*x1;%enthalpy dispalyed
    t0=h;
    plot([T1 t0],[x1 0],':',...
        'Color','r',...
        'Parent',handles.axes2);%wet bulb temperature lines
    text(T1,x1+0.4,...
        [num2str(T1) 'C'],...
        'Color','r',...
        'HorizontalAlignment','Right',...
        'VerticalAlignment','Baseline',...
        'Parent',handles.axes2);
    text(-13,3,...
        'Wet bulb temperature',...
        'FontWeight','normal',...
        'Color','r',...
        'HorizontalAlignment','Center',...
        'VerticalAlignment','Baseline',...
        'Parent',handles.axes2);
end
plot(get(gca,'xlim'),[x_max,x_max],'-k','linewidth',0.5);
hold(handles.axes2,'off');
ax1=gca;%get the current axes handle
set(handles.axes2,...
    'visible','on',...
    'units','centimeters',...
    'OuterPosition',get(handles.axes1,'OuterPosition'),...
    'Position',get(handles.axes1,'Position'),...
    'XAxisLocation','bottom',...
    'YAxisLocation','left',...
    'Color','none',...
    'XColor','k',...
    'YColor','r',...
    'xlim',get(handles.axes1,'xlim'),...
    'ylim',[0 x_max],...
    'Parent',gcf);
set(handles.axes2,'box','off');
ylabel(handles.axes2,'x - Specific humidity [g/kg dry air]');
xlabel(handles.axes2,'T - Dry bulb temperature [C]');
set(handles.axes2,'xgrid','on');


%hold(ax2,'on');
%hold(ax2,'off');

%handles.ax2old=ax2;
%ax2=axes(...
 %   'units','centimeters',...
  %  'OuterPosition',get(handles.axes1,'OuterPosition'),...
   % 'Position',get(handles.axes1,'Position'),...
    %'XAxisLocation','top',...
%    'YAxisLocation','left',...
 %   'Color','none',...
  %  'XColor','r',...
   % 'YColor','r',...
    %'xlim',get(ax1,'xlim'),...
%    'ylim',get(ax1,'ylim'),...
 %   'Parent',gcf);
