function [Cp,Rho,Lambda,Mu] = f_gasprop(Tm,Gas)
%foramt:    [Cp,Rho,Lambda,Mu] = f_gasprop(Tm,Gas)
%input:     Tm      -   [K]     mean temperature of the fill gas
%           Gas     -   [-]     type of fill gas:
%                               1   air
%                               2   argon
%                               3   krypton
%                               4   xenon
%output:    Cp [J/kgK] - specific heat capacity
%           Rho [kg/m^3] - density
%           Lambda [W/mK] - Thermal conductivity
%           Mu [kg/ms] - dynamic viscosity

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Adatok
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Tm=273.15;
%Gas=1;

%lgkri nyoms
P=101325; %[Pa]
%univerzlis gzlland
R=8314.41; %[J/kmol]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%air
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Cp_a cp_b
data(1).cp=[1002.737 1.2324e-2];
%M [kg/kmol]
data(1).M=[28.97];
%Lambda a b
data(1).lambda=[2.873e-3 7.76e-5];
%Mu a b
data(1).Mu=[3.723e-6 4.94e-8];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%argon
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Cp_a cp_b
data(2).cp=[521.9285 0];
%M [kg/kmol]
data(2).M=[39.948];
%Lambda a b
data(2).lambda=[2.285e-3 5.149e-5];
%Mu a b
data(2).Mu=[3.379e-6 6.451e-8];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%krypton
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Cp_a cp_b
data(3).cp=[248.0907 0];
%M [kg/kmol]
data(3).M=[83.80];
%Lambda a b
data(3).lambda=[9.443e-4 2.826e-5];
%Mu a b
data(3).Mu=[2.213e-6 7.777e-8];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Xenon
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%cp_a cp_b
data(4).cp=[158.3397 0];
%M [kg/kmol]
data(4).M=[131.30];
%Lambda a b
data(4).lambda=[4.538e-4 1.723e-5];
%Mu a b
data(4).Mu=[1.069e-6 7.414e-8];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Adatok lekrdezse a megfelel gztltsre
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if Gas==1
    Cp_a=data(1).cp(1);
    Cp_b=data(1).cp(2);
    M=data(1).M;
    Lambda_a=data(1).lambda(1);
    Lambda_b=data(1).lambda(2);
    Mu_a=data(1).Mu(1);
    Mu_b=data(1).Mu(2);
elseif Gas==2
    Cp_a=data(2).cp(1);   
    Cp_b=data(2).cp(2);
    M=data(2).M;
    Lambda_a=data(2).lambda(1);
    Lambda_b=data(2).lambda(2);
    Mu_a=data(2).Mu(1);
    Mu_b=data(2).Mu(2);
elseif Gas==3
    Cp_a=data(3).cp(1);  
    Cp_b=data(3).cp(2);
    M=data(3).M;
    Lambda_a=data(3).lambda(1);
    Lambda_b=data(3).lambda(2);
    Mu_a=data(3).Mu(1);
    Mu_b=data(3).Mu(2);
elseif Gas==4
    Cp_a=data(4).cp(1);  
    Cp_b=data(4).cp(2);
    M=data(4).M;
    Lambda_a=data(4).lambda(1);
    Lambda_b=data(4).lambda(2);
    Mu_a=data(4).Mu(1);
    Mu_b=data(4).Mu(2);
end

Cp=Cp_a+Cp_b*Tm;
Rho=(P*M)/(R*Tm);
Lambda=Lambda_a+Lambda_b*Tm;
Mu=Mu_a+Mu_b*Tm;